@@ -41,8 +41,6 @@ public:
     void openConnection() override;
     void closeConnection() override;
 
-    void setHost(const QString& host) override;
-
     void put(const QUrl& url, int _mode, KIO::JobFlags _flags) override;
     void get(const QUrl& url) override;
     void listDir(const QUrl& url) override;
@@ -65,7 +63,7 @@ protected:
     NFSFileHandle lookupFileHandle(const QString& path) override;
 
 private:
-    bool create(const QString& path, int mode, int& rpcStatus, CREATE3res& result);
+    NFSFileHandle create(const QString& path, int mode);
 
     bool getAttr(const QString& path, int& rpcStatus, GETATTR3res& result);
 
@@ -92,9 +90,6 @@ private:
     void completeUDSEntry(KIO::UDSEntry& entry, const fattr3& attributes);
     void completeBadLinkUDSEntry(KIO::UDSEntry& entry, const fattr3& attributes);
 
-    NFSSlave* m_slave;
-
-    QString m_currentHost;
     CLIENT* m_mountClient;
     int m_mountSock;
     CLIENT* m_nfsClient;
@@ -102,9 +97,6 @@ private:
 
     timeval clnt_timeout;
 
-    QHash<long, QString> m_usercache;
-    QHash<long, QString> m_groupcache;
-
     // The optimal read and write buffer sizes and read dir size, cached values
     uint32 m_readBufferSize;
     uint32 m_writeBufferSize;
