@@ -22,7 +22,9 @@
 
 #include <QFile>
 #include <QImage>
+#include <QMap>
 #include <QMimeDatabase>
+#include <QUrl>
 #include <QXmlStreamReader>
 
 #include <KZip>
@@ -71,12 +73,12 @@ bool EbookCreator::create(const QString &path, int width, int height, QImage &im
                 continue;
             }
 
-            const auto *entry = zip.directory()->entry(entryPath);
-            if (!entry || !entry->isFile()) {
+            const auto *entry = zip.directory()->file(entryPath);
+            if (!entry) {
                 return false;
             }
 
-            zipDevice.reset(static_cast<const KZipFileEntry *>(entry)->createDevice());
+            zipDevice.reset(entry->createDevice());
         }
 
         return createFb2(zipDevice.data(), image);
@@ -94,19 +96,16 @@ bool EbookCreator::createEpub(const QString &path, QImage &image)
 
     QScopedPointer<QIODevice> zipDevice;
     QString opfPath;
-    QString coverId;
     QString coverHref;
 
     // First figure out where the OPF file with metadata is
-    const auto *entry = zip.directory()->entry(QStringLiteral("META-INF/container.xml"));
+    const auto *entry = zip.directory()->file(QStringLiteral("META-INF/container.xml"));
 
-    if (!entry || !entry->isFile()) {
+    if (!entry) {
         return false;
     }
 
-    const auto *zipEntry = static_cast<const KZipFileEntry *>(entry);
-
-    zipDevice.reset(zipEntry->createDevice());
+    zipDevice.reset(entry->createDevice());
 
     QXmlStreamReader xml(zipDevice.data());
     while (!xml.atEnd() && !xml.hasError()) {
@@ -114,6 +113,7 @@ bool EbookCreator::createEpub(const QString &path, QImage &image)
 
         if (xml.isStartElement() && xml.name() == QLatin1String("rootfile")) {
             opfPath = xml.attributes().value(QStringLiteral("full-path")).toString();
+            break;
         }
     }
 
@@ -122,18 +122,19 @@ bool EbookCreator::createEpub(const QString &path, QImage &image)
     }
 
     // Now read the OPF file and look for a <meta name="cover" content="...">
-    entry = zip.directory()->entry(opfPath);
-    if (!entry || !entry->isFile()) {
+    entry = zip.directory()->file(opfPath);
+    if (!entry) {
         return false;
     }
 
-    zipEntry = static_cast<const KZipFileEntry *>(entry);
-
-    zipDevice.reset(zipEntry->createDevice());
+    zipDevice.reset(entry->createDevice());
 
     xml.setDevice(zipDevice.data());
 
     bool inMetadata = false;
+    bool inManifest = false;
+    QString coverId;
+    QMap<QString, QString> itemHrefs;
 
     while (!xml.atEnd() && !xml.hasError()) {
         xml.readNext();
@@ -142,28 +143,57 @@ bool EbookCreator::createEpub(const QString &path, QImage &image)
             if (xml.isStartElement()) {
                 inMetadata = true;
             } else if (xml.isEndElement()) {
-                break;
+                inMetadata = false;
             }
-        }
-
-        if (!inMetadata) {
             continue;
         }
 
-        if (xml.isStartElement() && xml.name() == QLatin1String("meta")) {
-            const auto attributes = xml.attributes();
-            if (attributes.value(QStringLiteral("name")) == QLatin1String("cover")) {
-                coverId = attributes.value(QStringLiteral("content")).toString();
+        if (xml.name() == QLatin1String("manifest")) {
+            if (xml.isStartElement()) {
+                inManifest = true;
+            } else if (xml.isEndElement()) {
+                inManifest = false;
+            }
+            continue;
+        }
+
+        if (xml.isStartElement()) {
+            if (inMetadata && (xml.name() == QLatin1String("meta"))) {
+                const auto attributes = xml.attributes();
+                if (attributes.value(QStringLiteral("name")) == QLatin1String("cover")) {
+                    coverId = attributes.value(QStringLiteral("content")).toString();
+                }
+            } else if (inManifest && (xml.name() == QLatin1String("item"))) {
+                const auto attributes = xml.attributes();
+                const QString href = attributes.value(QStringLiteral("href")).toString();
+                const QString id = attributes.value(QStringLiteral("id")).toString();
+                if (!id.isEmpty() && !href.isEmpty()) {
+                    // EPUB 3 has the "cover-image" property set
+                    const auto properties = attributes.value(QStringLiteral("properties")).toString();
+                    const auto propertyList = properties.split(QChar(' '), Qt::SkipEmptyParts);
+                    if (propertyList.contains(QLatin1String("cover-image"))) {
+                        coverHref = href;
+                        break;
+                    }
+                    itemHrefs[id] = href;
+                }
+            } else {
+                continue;
+            }
+
+            if (!coverId.isEmpty() && itemHrefs.contains(coverId)) {
+                coverHref = itemHrefs[coverId];
                 break;
             }
         }
     }
 
-    if (coverId.isEmpty()) {
+    if (coverHref.isEmpty()) {
         // Maybe we're lucky and the archive contains an iTunesArtwork file from iBooks
-        entry = zip.directory()->entry(QStringLiteral("iTunesArtwork"));
-        if (entry && entry->isFile()) {
-            return image.loadFromData(static_cast<const KZipFileEntry *>(entry)->data());
+        entry = zip.directory()->file(QStringLiteral("iTunesArtwork"));
+        if (entry) {
+            zipDevice.reset(entry->createDevice());
+            return image.load(zipDevice.data(), "");
         }
 
         // Maybe there's a file called "cover" somewhere
@@ -174,51 +204,23 @@ bool EbookCreator::createEpub(const QString &path, QImage &image)
                 continue;
             }
 
-            entry = zip.directory()->entry(name);
-            if (!entry || !entry->isFile()) {
+            entry = zip.directory()->file(name);
+            if (!entry) {
                 continue;
             }
 
-            if (image.loadFromData(static_cast<const KZipFileEntry *>(entry)->data())) {
+            zipDevice.reset(entry->createDevice());
+            if (image.load(zipDevice.data(), "")) {
                 return true;
             }
         }
-    }
-
-    // Read OPF file again from beginning and look for <item id="our id from above" href="...">
-    zipDevice->seek(0);
-    xml.setDevice(zipDevice.data());
-
-    bool inManifest = false;
-
-    while (!xml.atEnd() && !xml.hasError()) {
-        xml.readNext();
-
-        if (xml.name() == QLatin1String("manifest")) {
-            if (xml.isStartElement()) {
-                inManifest = true;
-            } else if (xml.isEndElement()) {
-                break;
-            }
-        }
-
-        if (!inManifest) {
-            continue;
-        }
-
-        if (xml.isStartElement() && xml.name() == QLatin1String("item")) {
-            const auto attributes = xml.attributes();
-            if (attributes.value(QStringLiteral("id")).compare(coverId, Qt::CaseInsensitive) == 0) {
-                coverHref = attributes.value(QStringLiteral("href")).toString();
-                break;
-            }
-        }
-    }
-
-    if (coverHref.isEmpty()) {
         return false;
     }
 
+    // Decode percent encoded URL
+    QByteArray encoded = itemHrefs[coverId].toUtf8();
+    coverHref = QUrl::fromPercentEncoding(encoded);
+
     // Make coverHref relative to OPF location
     const int lastOpfSlash = opfPath.lastIndexOf(QLatin1Char('/'));
     if (lastOpfSlash > -1) {
@@ -227,12 +229,13 @@ bool EbookCreator::createEpub(const QString &path, QImage &image)
     }
 
     // Finally, just load the cover image file
-    entry = zip.directory()->entry(coverHref);
-    if (!entry || !entry->isFile()) {
-        return false;
+    entry = zip.directory()->file(coverHref);
+    if (entry) {
+        zipDevice.reset(entry->createDevice());
+        return image.load(zipDevice.data(), "");
     }
 
-    return image.loadFromData(static_cast<const KZipFileEntry *>(entry)->data());
+    return false;
 }
 
 bool EbookCreator::createFb2(QIODevice *device, QImage &image)
