@@ -46,7 +46,6 @@
 #include <QMimeType>
 #include <QMimeDatabase>
 #include <QLibrary>
-#include <QTemporaryFile>
 #include <QDebug>
 
 #include <KFileItem>
@@ -57,18 +56,13 @@
 #include <KServiceTypeTrader>
 #include <KPluginLoader>
 
-#include <kaboutdata.h>
-
 #include <kio/thumbcreator.h>
 #include <kio/thumbsequencecreator.h>
 #include <kio/previewjob.h>
 
-#include <iostream>
 #include <limits>
 #include <QDirIterator>
 
-// Use correctly KComponentData instead of KApplication (but then no QPixmap)
-#undef USE_KINSTANCE
 // Fix thumbnail: protocol
 #define THUMBNAIL_HACK (1)
 
@@ -101,7 +95,6 @@
 //                Otherwise, the data returned is the image in PNG format.
 
 using namespace KIO;
-//using namespace KCodecs;
 
 extern "C" Q_DECL_EXPORT int kdemain( int argc, char **argv )
 {
@@ -109,25 +102,18 @@ extern "C" Q_DECL_EXPORT int kdemain( int argc, char **argv )
     nice( 5 );
 #endif
 
-#ifdef USE_KINSTANCE
-    KComponentData componentData("kio_thumbnail");
-#else
-
     QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
 
     // creating KApplication in a slave in not a very good idea,
     // as dispatchLoop() doesn't allow it to process its messages,
     // so it for example wouldn't reply to ksmserver - on the other
     // hand, this slave uses QPixmaps for some reason, and they
-    // need QApplication
-    // and HTML previews need even KApplication :(
+    // need QGuiApplication
     putenv(strdup("SESSION_MANAGER="));
 
-    // some thumbnail plugins reuse QWidget-tainted code for the rendering,
+    // Some thumbnail plugins use QWidget classes for the rendering,
     // so use QApplication here, not just QGuiApplication
     QApplication app(argc, argv);
-#endif
-
 
     if (argc != 4) {
         qCritical() << "Usage: kio_thumbnail protocol domain-socket1 domain-socket2";
@@ -505,6 +491,14 @@ QImage ThumbnailProtocol::thumbForDirectory(const QString& directory)
 
             dir.next();
 
+            if (dir.fileInfo().isSymbolicLink()) {
+                // Skip symbolic links, as these may point to e.g. network file
+                // systems or other slow storage. The calling code already
+                // checks for the directory itself, and if it is fine any
+                // contained plain file is fine as well.
+                continue;
+            }
+
             auto fileSize = dir.fileInfo().size();
             if ((fileSize == 0) || (fileSize > m_maxFileSize)) {
                 // don't create thumbnails for files that exceed
